==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Attributes.java <==
package com.example.model;

/**
 * Model for Attributes
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "Attributes", description = "Model for Attributes")
@javax.xml.bind.annotation.XmlRootElement(name = "Attributes")
public class Attributes implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String iType = null;
	
	/**
	 */
	public Attributes iType(java.lang.String iType) {
		setIType(iType);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("i_type")
	@javax.validation.constraints.NotNull
	public java.lang.String getIType() {
		return this.iType;
	}
	public void setIType(java.lang.String iType) {
		this.iType = iType;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Attributes attributes = (Attributes) o;
		return java.util.Objects.equals(this.iType, attributes.iType);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.iType);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Attributes {\n");
		
		sb.append("    iType: ").append(toIndentedString(this.iType)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Attributes.java <==
package com.example.model;

/**
 * Model for Attributes
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Attributes", description = "Model for Attributes")
@javax.xml.bind.annotation.XmlRootElement(name = "Attributes")
public class Attributes implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String iType = null;
	
	/**
	 */
	public Attributes iType(java.lang.String iType) {
		setIType(iType);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "i_type")
	@com.fasterxml.jackson.annotation.JsonProperty("i_type")
	@javax.validation.constraints.NotNull
	public java.lang.String getIType() {
		return this.iType;
	}
	public void setIType(java.lang.String iType) {
		this.iType = iType;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Attributes attributes = (Attributes) o;
		return java.util.Objects.equals(this.iType, attributes.iType);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.iType);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Attributes {\n");
		
		sb.append("    iType: ").append(toIndentedString(this.iType)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
